@@ -1,14 +1,12 @@
 package Astro::Constants;
 # ABSTRACT: this library provides physical constants for use in Astronomy
-$Astro::Constants::VERSION = '0.1100';
+$Astro::Constants::VERSION = '0.12';
+use 5.006;
 use strict;
 use warnings;
 
   'They are not constant but are changing still. - Cymbeline, Act II, Scene 5';
 
-
-1;
-
 __END__
 
 =pod
@@ -21,7 +19,7 @@ Astro::Constants - this library provides physical constants for use in Astronomy
 
 =head1 VERSION
 
-version 0.1100
+version 0.12
 
 =head1 SYNOPSIS
 
@@ -42,6 +40,13 @@ centimetres /grams /seconds
 with B<Astro::Constants::CGS> and metres /kilograms /seconds with
 B<Astro::Constants::MKS>.
 
+The C<:long> tag imports all the constants in their long name forms
+(i.e. GRAVITATIONAL).  Useful subsets can be imported with these tags:
+C<:fundamental> C<:conversion> C<:mathematics> C<:cosmology> 
+C<:planetary> C<:electromagnetic> or C<:nuclear>.
+Alternate names such as LIGHT_SPEED instead of SPEED_LIGHT or HBAR
+instead of H_BAR are imported with C<:alternates>.  I'd like
+to move away from their use, but they have been in the module for years.
 Short forms of the constant names are included to provide backwards
 compatibility with older versions based on Jeremy Bailin's Astroconst
 library and are available through the import tag C<:short>.
@@ -55,7 +60,6 @@ really inlined functions.
 Short name constants are constructed with the age-old idiom of fiddling
 with the symbol table using typeglobs, e.g. C<*PI = \3.14159>,
 and may be slower than the long name constants.
-I<This could do with some benchmarking.>
 
 =head2 Why use this module
 
@@ -563,9 +567,10 @@ as well as the alternate name C<NEUTRON_MASS> (imported using the :alternate tag
 
 =head2 MASS_HYDROGEN
 
-    1.67372e-24
+    1.6738e-27
 
-mass of Hydrogen atom
+mass of Hydrogen atom --   
+This value is from the IUPAC and is a little smaller than MASS_PROTON + MASS_ELECTRON, but within the uncertainty given here.  The current value is 1.008u +/- 0.0002 derived from a range of terrestrial materials.  If this is for precision work, you had best understand what you're using.  See https://iupac.org/what-we-do/periodic-table-of-elements/
 
 This constant is also available using the short name C<$A_mH>
 as well as the alternate name C<HYDROGEN_MASS> (imported using the :alternate tag for backwards compatibility)
@@ -618,17 +623,49 @@ Looking to fix this in future versions.
 Nothing is exported by default, so the module doesn't clobber any of your variables.  
 Select from the following tags:
 
--=for :list
--* :long                (use this one to get the most constants)
--* :short
--* :fundamental
--* :conversion
--* :mathematics
--* :cosmology
--* :planetary
--* :electromagnetic
--* :nuclear
--* :alternates
+=over 4
+
+=item *
+
+C<:long>                (use this one to get the most constants)
+
+=item *
+
+C<:short>
+
+=item *
+
+C<:fundamental>
+
+=item *
+
+C<:conversion>
+
+=item *
+
+C<:mathematics>
+
+=item *
+
+C<:cosmology>
+
+=item *
+
+C<:planetary>
+
+=item *
+
+C<:electromagnetic>
+
+=item *
+
+C<:nuclear>
+
+=item *
+
+C<:alternates>
+
+=back
 
 =head2 Deprecated functions
 
