@@ -14,6 +14,7 @@ use XML::LibXML;
 
 my ($tagname, );
 my $dzil_methodtag = q{=method};
+my $ALTERNATES_IN_LONG_TAG = 0;
 
 my $xml = XML::LibXML->load_xml(location => 'data/PhysicalConstants.xml');
 
@@ -58,7 +59,8 @@ for my $constant ( $xml->getElementsByTagName('PhysicalConstant') ) {
 			next unless $alternate =~ /\S/;
 
 			push @{$tagname->{alternates}}, $alternate;
-			push @{$tagname->{long}}, $alternate;
+			push @{$tagname->{long}}, $alternate if $ALTERNATES_IN_LONG_TAG;
+			# if alternateName tag has type="deprecated", put in $tagname->{deprecated} not $tagname->{long}
 			push @alternates, $alternate;
 
 			write_constant($mks_fh, ($values->{mks} || $values->{value}), $alternate) 
@@ -107,6 +109,7 @@ sub write_module_header {
 package $name;
 # ABSTRACT: this library provides physical constants for use in Astronomy
 
+use 5.006;
 use strict;
 use warnings;
 HEADER
@@ -135,12 +138,16 @@ sub pretty {
 
 sub precision {
 	my (\$name, \$type) = \@_;
+	warn "precision() requires a string, not the constant value" 
+		unless exists \$_precision{\$name};
+
 	return \$_precision{\$name}->{value};
 }
 
 our \@EXPORT_OK = qw( 
 	@{$tags->{long}}
 	@{$tags->{short}}
+	@{$tags->{alternates}}
 	pretty precision
 );
 
@@ -151,8 +158,10 @@ FOOT
 		print $fh "\t$name => [qw/ @{$tags->{$name}} /],\n";
 	}
 
+	print $fh ");\n";
+	print $fh "push \@EXPORT_OK, qw/@{$tags->{deprecated}}/;\n" 
+		if exists $tags->{deprecated} && @{$tags->{deprecated}};
 	print $fh <<FOOT;
-);
 
 'Perl is my Igor';
 FOOT
@@ -217,6 +226,13 @@ centimetres /grams /seconds
 with B<Astro::Constants::CGS> and metres /kilograms /seconds with
 B<Astro::Constants::MKS>.
 
+The C<:long> tag imports all the constants in their long name forms
+(i.e. GRAVITATIONAL).  Useful subsets can be imported with these tags:
+C<:fundamental> C<:conversion> C<:mathematics> C<:cosmology> 
+C<:planetary> C<:electromagnetic> or C<:nuclear>.
+Alternate names such as LIGHT_SPEED instead of SPEED_LIGHT or HBAR
+instead of H_BAR are imported with C<:alternates>.  I'd like
+to move away from their use, but they have been in the module for years.
 Short forms of the constant names are included to provide backwards
 compatibility with older versions based on Jeremy Bailin's Astroconst
 library and are available through the import tag C<:short>.
@@ -230,7 +246,6 @@ really inlined functions.
 Short name constants are constructed with the age-old idiom of fiddling
 with the symbol table using typeglobs, e.g. C<*PI = \3.14159>,
 and may be slower than the long name constants.
-I<This could do with some benchmarking.>
 
 =head2 Why use this module
 
@@ -256,17 +271,17 @@ to check your work?
 Nothing is exported by default, so the module doesn't clobber any of your variables.  
 Select from the following tags:
 
--=for :list
--* :long                (use this one to get the most constants)
--* :short
--* :fundamental
--* :conversion
--* :mathematics
--* :cosmology
--* :planetary
--* :electromagnetic
--* :nuclear
--* :alternates
+=for :list
+* C<:long>                (use this one to get the most constants)
+* C<:short>
+* C<:fundamental>
+* C<:conversion>
+* C<:mathematics>
+* C<:cosmology>
+* C<:planetary>
+* C<:electromagnetic>
+* C<:nuclear>
+* C<:alternates>
 
 POD
 }
@@ -400,7 +415,6 @@ documentation.
 
 =cut
 
-1;
 POD
 }
 
